#
# spec file for package alpine
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# grep '\*version' for new pico version number
# grep 'PILOT_VERSION' for new pilot version number
Name:           alpine
# For debugging only:
%define		build_vanilla		0
Version:        2.26
Release:        29.4
Summary:        Mail User Agent
License:        Apache-2.0
Group:          Productivity/Networking/Email/Clients
URL:            https://alpineapp.email/
#Git-Clone:     https://repo.or.cz/alpine.git

#Source:         %name-%version.tar.xz
Source:         https://alpineapp.email/alpine/release/src/alpine-%version.tar.xz
Source2:        https://alpineapp.email/alpine/release/src/sig/alpine-%version.tar.xz.sig
Source3:        %name.png
Source4:        %name.desktop
Source9:        UPDATING.txt
Patch2:         make-use-of-strncat-safer.diff
Patch3:         operation-may-be-undefined-warning.diff
Patch4:         fix-implicit.patch
Patch5:         alpine-gcc44.diff
Patch6:         alpine-timestamp.patch
Patch10:        pico-fix-spurious-undef-warnings.diff
Patch20:        pine-expression-warnings.diff
Patch60:        signal-and-panic-improvements.diff
Patch61:        return-values.diff
Patch62:        alpine-qsort.patch
#
# Eduardo Chappa's patches.
# http://patches.freeiz.com/alpine/
#
Source600:      chappa-colortext.txt
Patch600:       chappa-colortext.patch
Source601:      chappa-fancy.txt
Patch601:       chappa-fancy.patch
Source603:      chappa-insertpat.txt
Patch603:       chappa-insertpat.patch
Source604:      chappa-maildir.txt
Patch604:       chappa-maildir.patch
Source614:      chappa-fillpara.txt
Patch614:       chappa-fillpara.patch
Source615:      chappa-fromheader.txt
Patch615:       chappa-fromheader.patch
Source616:      chappa-rules.txt
Patch616:       chappa-rules.patch
Source617:      chappa-DelText.txt
Patch617:       chappa-DelText.patch
BuildRequires:  autoconf >= 2.69
BuildRequires:  krb5-devel
BuildRequires:  libtool
BuildRequires:  ncurses-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  update-desktop-files
BuildRequires:  xz
# pgp4pine requires pine: (6.20 is what alpine writes to ~/.pinerc)
Provides:       pine = 6.20
Obsoletes:      pine4
Provides:       pine4

%description
Alpine is a display-oriented email client that is suitable for both
the inexperienced email user as well as for the most demanding of
power users. Alpine is based on the Pine® Message System, which was
also developed at the University of Washington. Alpine can be learned
by exploration and the use of context-sensitive help. The user
experience is highly customizable through the use of the Alpine Setup
command.

%package -n pico
Summary:        A small, easy to use editor
Group:          Productivity/Editors/Other
Version:        5.09
Release:        29.4

%description -n pico
Pico is a simple, display-oriented text editor based on the Pine
message system composer. As with Pine, commands are displayed at the
bottom of the screen, and context-sensitive help is provided.
Characters are inserted into the text as they are typed.

%package -n pilot
Summary:        Simple file system browser
Group:          Productivity/File utilities
Version:        2.99
Release:        29.4

%description -n pilot
Pilot is a simple, display-oriented file system browser based on the
Pine message system composer. As with Pine, commands are displayed at
the bottom of the screen, and context-sensitive help is provided.

%prep
%setup -q
%if !0%{?build_vanilla}
#
# This is here to support checking if any patches add new warnings:
#
if [ ! -s %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log ]; then
	echo "No warnings check possible, set build_vanilla to 1 and"
	echo "add compile-warnings-%{suse_version}-%{_arch}.log from"
	echo "that build to the rpm build process so that it's found here".
else
	sed 's/:[0-9]*//' %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log \
		>compile-warnings-allowed.log
fi
#
# "Chappa" patches
#
%patch -P 600 -p1
%patch -P 601 -p1
%patch -P 603 -p1
%patch -P 604 -p1
%patch -P 614 -p1
%patch -P 615 -p1
%patch -P 616 -p1
%patch -P 617 -p1
#
# SuSE patches - warning fixes, etc:
#
%patch -P 2 -p1
%patch -P 3 -p1
%patch -P 4 -p1
%patch -P 5 -p1
%patch -P 6 -p1
%patch -P 10 -p1
%patch -P 20 -p1
%patch -P 60 -p1
%patch -P 61 -p1
%patch -P 62
%endif

%build
#
# Comment on disabled warnings: The disabled warnings are rather harmless
# and disabling them allows to focus on the really serious warnings:
#
export CFLAGS="${RPM_OPT_FLAGS/-O2/-Os} \
		-Wno-unused-value -fno-strict-aliasing -Wno-pointer-sign -Wno-unused \
		-Wno-address \
"
#
# On -Waddress:
#
# Added with gcc-4.2: It warns when the address of a variable (not a pointer)
# is used in an expression. Since addresses of variables are always non-zero,
# they are always true and can be safely removed from the expression,
# but the code is safe nontheless.
#
# -Waddress generates >100 warnings in alpine and we disabled them to
# concentrate on the really important warnings which could be real bugs better.
#
:
#
# Used in conjunction with signal-and-panic-improvements.diff:
#
export LDFLAGS="-rdynamic" # -rdynamic is used for backtrace_symbols:
:
autoreconf -fiv
%configure \
	--with-ssl-dir="%{_prefix}"			\
	--with-smtp-msa="%{_sbindir}/sendmail"		\
	--with-password-prog="%{_bindir}/passwd"	\
	--with-npa="%{_bindir}/inews"			\
	--with-spellcheck-prog="please set Speller to eg. 'aspell -c' in SETUP/Configuration"\
	--with-system-pinerc=%_sysconfdir/pine.conf		\
	--with-system-fixed-pinerc=%_sysconfdir/pine.conf.fixed \
	--with-debug-level=0				\
	--with-debug-files=2				\
	--with-file=.alpine-debug			\
	--with-default-mail-directory=Mail		\
	--with-web-bin=%_libdir/%name                   \
	--with-passfile=.pinepw || {
	grep -B9 -A20 'failed program was' config.log | grep -A24 checking
	exit 5
}
%{?fedora_version: tag=LFD}
%{?mandriva_version: tag=LMD}
%{?redhat_version: tag=LRH}
%{?centos_version: tag=LRH}
%{?suse_version: tag=LSU}
perl -i -pe 's{(define SYSTYPE) "LNX"}{$1 "'"$tag"'"}g' include/config.h

#
# imap does not use CFLAGS from configure, needs EXTRACFLAGS/EXTRALDFLAGS:
#
%make_build EXTRACFLAGS="$CFLAGS" EXTRALDFLAGS="$EXTRALDFLAGS" \
	MAILSPOOL="%{_localstatedir}/mail" -j1

%install
%make_install
#
# When called as alpinef, alpine uses function keys instead of Control keys:
#
ln %{buildroot}/%{_bindir}/alpine %{buildroot}/%{_bindir}/alpinef
install -D -m644 %{SOURCE3} %{buildroot}/%{_datadir}/pixmaps/%name.png
install -D -m644 %{SOURCE4} %{buildroot}/%{_datadir}/applications/%name.desktop
%suse_update_desktop_file %name
:
ln -sf		 alpine			%{buildroot}/%{_bindir}/pine
:
install -m755 pico/{pico,pilot}		%{buildroot}/%{_bindir}
install -m644 doc/man1/{pico.1,pilot.1}	%{buildroot}/%{_mandir}/man1/

%check
#since there are no logs in the package at the moment, there are no checks,
#but the warning logs can be recreated for regression tracking in warnings:
if [  -s %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log ]; then
    grep -e '^[a-z0-9_]*.[cho]:' -e 'Entering directory' make.log |
	sed "s/^make\[.\]: //;/Entering directory/s/[\`']//g;" \
	>compile-warnings-%{suse_version}-%{_arch}.log
    # Sort the combined allowed warnings:
    grep -v -e 'In function' -e 'Entering directory' \
	compile-warnings-allowed.log |
	    sort -u > compile-warnings-%{suse_version}-%{_arch}-reference.sort
    # Sort the warnings which occured now:
    grep -v -e 'In function' -e 'Entering directory' \
	compile-warnings-%{suse_version}-%{_arch}.log |
	    sed 's/:[0-9]*//' | sort -u \
		>compile-warnings-%{suse_version}-%{_arch}-thisbuild.sort
    # diff them:
    diff compile-warnings-%{suse_version}-%{_arch}-{reference,thisbuild}.sort |
	tee	  compile-warnings-%{suse_version}-%{_arch}-sorted.diff
    if test    -s compile-warnings-%{suse_version}-%{_arch}-sorted.diff; then
	grep '^>' compile-warnings-%{suse_version}-%{_arch}-sorted.diff >new-warnings ||:
	if [ -s new-warnings ]; then
		diff -u %{_sourcedir}/compile-warnings-%{suse_version}-%{_arch}.log \
			compile-warnings-%{suse_version}-%{_arch}.log ||
		echo "New warnings:"
		cat new-warnings
		sed 's/> //;s/:/:[0-9]*:/' new-warnings >new-warnings.pattern
		: diff:  %_builddir}/compile-warnings-%{suse_version}-%{_arch}-sorted.diff
		grep -B1 -f new-warnings.pattern compile-warnings-%{suse_version}-%{_arch}.log
		grep -e 'Entering directory' -f new-warnings.pattern \
			compile-warnings-%{suse_version}-%{_arch}.log |
				grep -B1 -f new-warnings.pattern |
					tee warnings.where
		while IFS='[: ]' read file line message; do
			if [ "$file" = Entering ]; then
				dir="${message#%_builddir/%buildsubdir/}"
			else
				path="$dir/$file"
				echo "$path:$line: $message"	>>warnings-with-code
				head -"$line" "$path"|tail -1	>>warnings-with-code
			fi
		done <warnings.where
		cat warnings-with-code
		exit 5
	else
		echo "Fixed warnings:"
		grep '^<' compile-warnings-%{suse_version}-%{_arch}-sorted.diff
	fi
    else
	echo "No fixed warnings and no new warnings"
    fi
fi

%files
%doc %{_mandir}/man1/alpine.*
%doc %{_mandir}/man1/rpdump.*
%doc %{_mandir}/man1/rpload.*
%doc README
%license LICENSE NOTICE
%doc doc/mailcap.unx doc/mime.types doc/tech-notes/tech-notes.txt doc/tech-notes/*.html
%{_bindir}/*pine
%{_bindir}/alpinef
%{_bindir}/rp*
%{_datadir}/applications/%name.desktop
%{_datadir}/pixmaps/%name.png

%files -n pico
%{_bindir}/pico
%doc %{_mandir}/man1/pico.*

%files -n pilot
%{_bindir}/pilot
%doc %{_mandir}/man1/pilot.*

%changelog
* Tue May 21 2024 Reinhard Max <max@suse.com>
- boo#1224533: Add alpine-qsort.patch to fix build with gcc 14.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Thu Sep  8 2022 Jan Engelhardt <jengelh@inai.de>
- Disable parallel build, fails to produce a result
* Fri Jun 10 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.26
  * Alpine is built with password file support by default. If
    Alpine is built with SMIME support and the password file does
    not exist, then Alpine will create it by default and encrypt
    it.
  * In the past, Alpine did not recognize images embedded in an
    HTML file, so now it does and a link to open them is given.
    Additionally, Alpine did not pass these images to an external
    browser for display using the external command; it does so now.
  * Support for code_verifier and code_challenge when generating
    a refresh token and access token in Gmail and Outlook using
    the S256 method and plain method.
  * Changed the redirect_uri scheme for Gmail, as Google is
    deprecating the use of oob. Changed to http://localhost.
    Users are supposed to enter the URL they see in their browser
    in place of the code.
  * Added support to the LDAP attribute "userCertificate";
  * If new mail has arrived when a user is closing a mailbox,
    Alpine will also announce how many new messages have arrived.
* Tue Mar 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.25.1
  * In the past, Alpine did not recognize images embedded in an
    HTML file, so now it does and a link to open them is given.
  * Support for code_verifier and code_challenge when generating
    a refresh token and access token in Gmail and Outlook using
    the S256 method and plain method.
  * Alpine is modified to not to attempt to continue a draft
    message if the draft folder is empty. (Some servers do not
    allow the Drafts folder to be removed, even when it is
    empty.)
  * Improvements to the screen that allows a user to select the
    client-id when a user attempts to login to a server and more
    than one client-id is available for that server.
* Wed Nov 24 2021 Jan Engelhardt <jengelh@inai.de>
- Delete chappa-WrtAcc.patch. Under Linux, one can use the Compose
  key feature. (And for Windows, the putty client can provide an
  equivalent Compose key feature.)
* Sun Sep 19 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.25
  * New configuration variable VAR_ssl-ciphers that allows users
    to list the ciphers to use when connecting to a SSL
    server.
  * New hidden feature FEAT_enable-delete-before-writing to add
    support for terminals that need lines to be deleted before
    being written.
  * Always follow ‘suppress-asterisks-in-password-prompt’ setting
    in the various password prompts.
  * Fixed a memory corruption when alpine searches for a string
    that is an incomplete utf8 string in a local folder.
  * Fixed: When forwarding a message, replacing an attachment
    might make Alpine re-attach the original attachment.
  * bsc#1189316, CVE-2021-38370: The c-client library parses
    information from an IMAP server during non-authenticated state
    which could lead to denial of service.
* Tue May 25 2021 Jan Engelhardt <jengelh@inai.de>
- Add chappa-DelText.patch [boo#1182236]
* Sun May 16 2021 Callum Farmer <gmbr3@opensuse.org>
- Set system mail directory to /var/mail
* Fri Jan 15 2021 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.24
  * A few crash fixes
  * Implementation of XOAUTH2 for Yahoo! Mail.
* Fri Oct  2 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.23.2
  * Expansion of the configuration screen for XOAUTH2 to include
    username, and tenant.
  * Alpine uses the domain in the From: header of a message
    to generate a message-id and suppresses all information
    about Alpine, version, revision, and time of generation
    of the message-id from this header.
  * Alpine does not generate Sender or X-X-Sender by default by
    enabling [X] Disable Sender as the default.
  * Alpine does not disclose User Agent by default by enabling
    [X] Suppress User Agent by default.
  * When messages are selected, pressing the ';' command to
    broaden or narrow a search, now offers the possibility to
    completely replace the search, and is almost equivalent to
    being a shortcut to "unselect all messages, and select
    again".
* Mon Sep  7 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.23
  * Fixes bsc#1173281, CVE-2020-14929: Alpine silently proceeds to
    use an insecure connection after a /tls is sent in certain
    circumstances.
  * Implementation of XOAUTH2 authentication support for Outlook.
  * Add support for the OAUTHBEARER authentication method in Gmail.
  * Support for the SASL-IR IMAP extension.
  * Alpine can pass an HTML message to an external web browser,
    by using the "External" command in the ATTACHMENT INDEX
    screen.
- Drop extern.diff (merged)
* Sun Jun  7 2020 Jan Engelhardt <jengelh@inai.de>
- Add extern.diff.
- Mark license texts as %%license.
* Thu May  7 2020 Jan Engelhardt <jengelh@inai.de>
- Update to release 2.22
  * Support for XOAUTH2 authentication method in Gmail.
  * NTLM authentication support with the ntlm library.
  * Added the "/tls1_3" flag for servers that support it.
  * Add the "g" option to the select command that works in IMAP
    servers that implement the X-GM-EXT-1 capability (such as the
    one offered by Gmail).
  * Added "/auth=XYZ" to the way to define a server. This allows
    users to select the method to authenticate to an IMAP, SMTP
    or POP3 server. Examples are /auth=plain, or /auth=gssapi,
    etc.
  * When a message is of type multipart/mixed, and its first part
    is multipart/signed, Alpine will include the text of the
    original message in a reply message, instead of including a
    multipart attachment.
  * Added backward search in the index screen.
  * pico: Add -dict option to Pico, which allows users to choose a
    dictionary when spelling.
- Drop /usr/bin/mailutil, it is not built by default anymore.
- Remove alpine-pinepw.patch (merged upstream)
- Add description files for patches 600-616. These live in a
  separate file because (a) upstream does not offer the description
  as part of the patch file, (b) redownloading the patches would
  nuke any added description due to <a>.
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Add return-values.diff to unbreak build.
- Use more macros for standard dirs in the build recipe.
* Thu May  2 2019 Reinhard Max <max@suse.com>
- Fix initialisation of encrypted password store (bsc#1133597,
  alpine-pinepw.patch).
* Thu Nov  8 2018 Michal Svec <msvec@suse.com>
- updated upstream URL
* Mon Jul  3 2017 jengelh@inai.de
- imap is bundled with alpine since a while, so there is no need
  for imap-devel anymore (whose removal is planned for
  openSUSE:Factory).
* Tue Mar 21 2017 opensuse@dstoecker.de
- add chappa patch to add own rules (chappa-rules.patch)
- add chappa patch to change from header (chappa-fromheader.patch)
- add chappa patch to better justify paragraphs (chappa-fillpara.patch)
- drop empty lint.diff
* Tue Mar 21 2017 max@suse.com
- New version 2.21:
  * New SHORTSUBJECT, SHORTSUBJKEY and SHORTSUBJKEYINIT token for
    index format
  * New SMARTTIME24 token for index screen.
  * Added support for RFC 2971 - IMAP ID extension.
  * SMIME: Upgrade the default signature digest from SHA-1 to
    SHA-256.
  * SMIME: Turn off automatic signing and encrypting of a message
    when bouncing.
  * The complete change list can be viewed by pressing "R"
    in the Alpine main menu.
- Updated "Chappa" patches to the latest version.
- Obsolete patches:
  * alpine-no-add-needed.patch
  * chappa-ignoresize.patch
  * chappa-unixnullbug.patch
  * pico-stripwhitespace.diff
  * pine-nonvoid-function.patch
* Mon Apr  4 2016 kukuk@suse.de
- Remove BuildRequires for libgssglue (via libgssapi provides),
  unused since krb5_gssapi is used.
* Fri Mar  4 2016 olaf@aepfle.de
- Remove timestamp from binary
  alpine-timestamp.patch
* Wed Mar 25 2015 jengelh@inai.de
- Update to new upstream release 2.20
  * Upgrade UW-IMAP to Panda IMAP from github.com/jonabbey/panda-imap
  * S/MIME: Add screen to manage certificates.
  * S/MIME: Signatures are validated using the user's certificates
  instead of the ones included in the message. Behavior can be
  disabled by disabling the option "Validate Using Certificate
  Store Only" which is enabled by default.
  * S/MIME: add the sender certificate to the list of certificates
  in encrypted messages to make it possible for the sender to
  decrypt the message they sent.
  * S/MIME: Forwarding a message will include the signed part as part
  of the text and not as a multipart message, just as the reply
  command does.
  * Add support to selective expunge through a subcommand of the
  select-apply commands.
  * Pico: New subcommand of the search command, allows to reverse the
  direction of search.
  * Add /tls1, /tls1_1, /tls1_2 and /dtls1 to the definition of a
  server to use different ways to connect using ssl, for example
  {server.com/tls1} will attempt to connect to server.com at the
  ssl imap port (port 993) and establish a connection using TLSv1.
  These flags can be used in conjunction with the /ssl flag, the
  ssl flag is redundant. Conversely, however, the /ssl flag does
  not imply any of these flags; the /ssl flag means SSLv3 or, if
  not available, SSLv2 in the SSL port.
  * Alpine does not attempt to automatically reopen a collection that
  was not opened due to cancellation by the user. Instead, the user
  must try to open it explicitly.
  * Experimental: Write the content-type of a message in lowercase,
  as some non-compliant servers do not understand uppercase
  content-type.
  * Opening a folder updates recent count in maildrops (this
  already works for other types of folders)
  * Pico: Justification works without need of a predefined quote
  string. This allows justification of blocks of text that are
  indented with spaces.
  * Decode the name of attachment names, so they can be written as
  part of the description of the part.
  * Replace tabs by spaces in From and Subject fields to control for
  size in screen of these fields. Change only in index screen
  display.
- Drop alpine-month_name-utf8.patch (solved differently upstream),
  drop alpine-mime-type-workaround.patch (merged upstream)
- Add lint.diff to workaround new source code problems
* Mon Mar  3 2014 jengelh@inai.de
- The pico and pilot standalone programs have version numbers of
  their own; expose these in the .spec file
* Wed Jan 22 2014 max@suse.com
- Add alpine-mime-type-workaround.patch:
  Send mime type in lowercase to work around MUAs that can't cope
  with upper case mime type strings in the Content-Type header
  such as the webmailer of GMX.  This is a backport from the
  current development release and will become obsolete with the
  next version upgrade.
* Mon Sep  2 2013 jengelh@inai.de
- Update to new upstream release 2.11
  * Increase encryption of S/MIME encrypted messages.
  * Pico: Improvements in justification of paragraphs: lines that
  begin with a quote string, followed by a space were considered
  individual paragraphs, now they are considered part of a paragraph.
  * Unix Alpine: Allow local .pinerc file to be a symbolic link.
  * Experimental extended support of recognition of UTF-8 in urls
  * Added recognition of ws and wss URIs.
  * Add ability to color folder names, directory names, and text in
  the FOLDER SCREEN.
  * Add the ability to color any token used in the display of the
  INDEX SCREEN.
  * New option preserve-original-fields that adds the ability to
  preserve To: and Cc: fields when replying to a message, as
  specified by original sender.
  * Added Quota subcommands for printing, forwarding, saving, etc.
- Refresh from homepage (and save as unified): chappa-*.patch
- Refresh for -p1: operation-may-be-undefined-warning.diff,
  fix-implicit.patch, alpine-gcc44.diff
- Drop quilt-patches/alpine-2.00-as_needed.patch (merged upstream)
* Wed May 22 2013 jengelh@inai.de
- Update to new upstream release 2.10
  * Quota report for IMAP folders that support it
  (press the "@" command in the index screen of such folder).
  * Search a folder for the content of any header with the ";"
  command.
  * Foreign characters are decoded correctly in IMAP folders.
  * Recognition of proper mime type for docx, xlsx, and pptx files.
  * When composing a message, Alpine will create a new thread when
  the subject is erased.
- Uncompress patches, since quilt does not like working with them
- Remove because merged upstream: chappa-filterflagbug.patch(.gz),
  chappa-nlinfobug.patch(.gz), chappa-replacebug.patch(.gz),
  chappa-searchheader.patch(.gz), chappa-streamlock.patch(.gz)
- Rediff to clear fuzz: alpine-no-add-needed.patch,
  pine-nonvoid-function.patch
- Remove because no longer applies and total lack of description
  as per Patch Guidelines:
  alpine-no-add-needed.patch
* Wed May 22 2013 jengelh@inai.de
- Remove old SUSE definitions
* Fri Jul 27 2012 aj@suse.de
- Include sys/resource.h for getrlimit.
* Wed Feb  8 2012 puzel@suse.com
- clean up spec file
* Mon Oct 17 2011 max@suse.com
- Fix two instances of premature closedir() and a potential buffer
  overflow in the maildir handler (alpine-maildir-closedir.patch).
* Tue Oct 11 2011 max@suse.com
- Fix and extend operation-may-be-undefined-warning.diff
  (bnc#558841)
- Overhaul RPM summary and description.
- Month names containing non-ASCII characters were rendered
  incorrectly in non-UTF8 locales (bnc#597744).
* Mon Oct 10 2011 max@suse.com
- Explicitly set the ssl prefix dir to fix build on ARM.
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Sat Sep  3 2011 crrodriguez@opensuse.org
- Fix build with no-add-needed
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Wed Jul 29 2009 max@suse.de
- Included the latest bugfix-patches from Eduardo Chappa:
- replacebug: Fix a bug in Pico which makes it not update the
  screen.
- unixnullbug: Fix a bug that makes Alpine crash when opening a
  unix type folder.
- streamlock: Fix a bug that makes Alpine crash when suspending it.
- filterflagbug: Fix a bug in Alpine that makes it not to set a
  flag in a filtered message (bnc#342075).
- nlinfobug: Fix a bug in Pico and Pilot that makes them crash
  for bad locale information.
- unverified: Fix a bug that makes Alpine not to give a warning
  if the Newsgroup header is present
* Sat Jun 20 2009 cmorve69@yahoo.es
- fixed build with --as-needed
* Tue Jun  2 2009 coolo@suse.de
- fix compilation with gcc44
* Wed Oct 15 2008 max@suse.de
- lzma is no longer needed for building.
* Thu Oct  9 2008 meissner@suse.de
- added unistd.h for prototypes
* Mon Sep 29 2008 max@suse.de
- Update to version 2.00 and the related Chappa patches.
- Changes include:
  * Experimental S/MIME support added in UNIX versions of Alpine
  * Enhance address completion in the composer (TAB command)
  * Add line wrapping when displaying PRE formatted sections of
    HTML
  * Fix a crash when using tab-completion for selecting a Save
    filename
  * Fix viewing, printing, exporting, replying, and bouncing of
    message digests.
  * The Unknown Character Set option did not work correctly
    interpreting unknown characters in message headers
  * Crash when TABing to next folder, the next folder with new
    mail is a POP folder, and there is a more than 10 minute
    pause between typing the TAB and typing the Yes
- For more details, see:
  http://www.washington.edu/alpine/changes/1.10-to-2.00.html
* Sat Apr 26 2008 coolo@suse.de
- fix build
* Fri Apr 25 2008 bk@suse.de
- Update to alpine-1.10 and update fixes suggested for this version
* Fri Jan 11 2008 bk@suse.de
- Update to alpine-1.00 and apply fixes suggested for this version
* Tue Sep 25 2007 bk@suse.de
- Use only select patches from Eduardo (fixes crash in mail reader)
* Wed Sep 19 2007 bk@suse.de
- Remove files with unclear license from packaged sources (#308533)
- Add small bug fix: Postponed messages which were labelled as UTF-8
- Spec file cleanup: Comments improved, obsoleted some warning flags
* Tue Sep  4 2007 bk@suse.de
- Update to final prerelease 0.9999 with updates from Eduardo Chappa
* Thu Aug  9 2007 bk@suse.de
- add a number of critcally needed fixes for some crashes (and more)
* Thu Aug  2 2007 bk@suse.de
- initial version 0.999 + assorted feature patches and some fixes
